@@ -2,10 +2,12 @@ import logging
 import click
 import tempfile
 import sqlite3
-from Crypto.Cipher import AES
+from cryptography.hazmat.primitives.ciphers import Cipher, algorithms, modes
+from cryptography.hazmat.backends import default_backend
 from pprint import pformat as pf
 import attr
 from android_backup import AndroidBackup
+from typing import Iterator
 
 logging.basicConfig(level=logging.INFO)
 _LOGGER = logging.getLogger(__name__)
@@ -13,6 +15,7 @@ _LOGGER = logging.getLogger(__name__)
 
 @attr.s
 class DeviceConfig:
+    """A presentation of a device including its name, model, ip etc."""
     name = attr.ib()
     mac = attr.ib()
     ip = attr.ib()
@@ -21,27 +24,43 @@ class DeviceConfig:
 
 
 class BackupDatabaseReader:
+    """Main class for reading backup files.
+    The main usage is following:
+
+    .. code-block:: python
+
+        r = BackupDatabaseReader()
+        devices = r.read_tokens("/tmp/database.sqlite")
+        for dev in devices:
+            print("Got %s with token %s" % (dev.ip, dev.token)
+    """
     def __init__(self, dump_raw=False):
         self.dump_raw = dump_raw
 
     @staticmethod
     def dump_raw(dev):
+        """Dump whole database."""
         raw = {k: dev[k] for k in dev.keys()}
         _LOGGER.info(pf(raw))
 
     @staticmethod
     def decrypt_ztoken(ztoken):
+        """Decrypt the given ztoken, used by apple."""
         if len(ztoken) <= 32:
             return ztoken
 
         keystring = '00000000000000000000000000000000'
         key = bytes.fromhex(keystring)
-        cipher = AES.new(key, AES.MODE_ECB)
-        token = cipher.decrypt(bytes.fromhex(ztoken[:64]))
+        cipher = Cipher(algorithms.AES(key), modes.ECB(),
+                        backend=default_backend())
+        decryptor = cipher.decryptor()
+        token = decryptor.update(bytes.fromhex(ztoken[:64])) \
+                + decryptor.finalize()
 
         return token.decode()
 
-    def read_apple(self):
+    def read_apple(self) -> Iterator[DeviceConfig]:
+        """Read Apple-specific database file."""
         _LOGGER.info("Reading tokens from Apple DB")
         c = self.conn.execute("SELECT * FROM ZDEVICE WHERE ZTOKEN IS NOT '';")
         for dev in c.fetchall():
@@ -56,7 +75,8 @@ class BackupDatabaseReader:
             config = DeviceConfig(name=name, mac=mac, ip=ip, model=model, token=token)
             yield config
 
-    def read_android(self):
+    def read_android(self) -> Iterator[DeviceConfig]:
+        """Read Android-specific database file."""
         _LOGGER.info("Reading tokens from Android DB")
         c = self.conn.execute("SELECT * FROM devicerecord WHERE token IS NOT '';")
         for dev in c.fetchall():
@@ -72,7 +92,10 @@ class BackupDatabaseReader:
                                   model=model, token=token)
             yield config
 
-    def read_tokens(self, db):
+    def read_tokens(self, db) -> Iterator[DeviceConfig]:
+        """Read device information out from a given database file.
+
+        :param str db: Database file"""
         self.db = db
         _LOGGER.info("Reading database from %s" % db)
         self.conn = sqlite3.connect(db)
